@@ -131,4 +131,8 @@ var (
 	// CsiHostpathDriverAssets assets for csi-hostpath-driver addon
 	//go:embed csi-hostpath-driver/deploy/*.tmpl csi-hostpath-driver/rbac/*.tmpl
 	CsiHostpathDriverAssets embed.FS
+
+	// PortainerAssets assets for portainer addon
+	//go:embed portainer/portainer.yaml.tmpl
+	PortainerAssets embed.FS
 )
