@@ -30,7 +30,7 @@ gcloud cloud-shell ssh --authorize-session << EOF
  DRIVER="docker"
  JOB_NAME="Docker_Cloud_Shell"
  CONTAINER_RUNTIME="docker"
- EXTRA_TEST_ARGS="-test.run (TestFunctional|TestAddons)"
+ EXTRA_TEST_ARGS="-test.run (TestFunctional|TestAddons|TestStartStop)"
 
  # Need to set these in cloud-shell or will not be present in common.sh
  MINIKUBE_LOCATION=$MINIKUBE_LOCATION
