@@ -24,6 +24,9 @@ docker login -u ${DOCKERHUB_USER} -p ${DOCKERHUB_PASS}
 # Make sure gh is installed and configured
 ./hack/jenkins/installers/check_install_gh.sh
 
+# Make sure golang is installed and configured
+./hack/jenkins/installers/check_install_golang.sh "/usr/local" || true
+
 # Let's make sure we have the newest kicbase reference
 curl -L https://github.com/kubernetes/minikube/raw/master/pkg/drivers/kic/types.go --output types-head.go
 # kicbase tags are of the form VERSION-TIMESTAMP-PR, so this grep finds that TIMESTAMP in the middle
@@ -46,13 +49,13 @@ if [[ -z $KIC_VERSION ]]; then
 	now=$(date +%s)
 	KV=$(egrep "Version =" pkg/drivers/kic/types.go | cut -d \" -f 2 | cut -d "-" -f 1)
 	GCR_REPO=gcr.io/k8s-minikube/kicbase-builds
-	DH_REPO=kicbase/build
+	DH_REPO=docker.io/kicbase/build
 	export KIC_VERSION=$KV-$now-$ghprbPullId
 else
 	# Actual kicbase release here
 	release=true
 	GCR_REPO=${GCR_REPO:-gcr.io/k8s-minikube/kicbase}
-	DH_REPO=${DH_REPO:-kicbase/stable}
+	DH_REPO=${DH_REPO:-docker.io/kicbase/stable}
 	export KIC_VERSION
 fi
 GCR_IMG=${GCR_REPO}:${KIC_VERSION}
@@ -68,10 +71,7 @@ ec=$?
 if [ $ec -gt 0 ]; then
 	if [ "$release" = false ]; then
 		gh pr comment ${ghprbPullId} --body "Hi ${ghprbPullAuthorLoginMention}, building a new kicbase image failed.  
-		See the logs at:
-	       	```
-		https://storage.cloud.google.com/minikube-builds/logs/${ghprbPullId}/${ghprbActualCommit:0:7}/kic_image_build.txt
-		```
+		See the logs at: https://storage.cloud.google.com/minikube-builds/logs/${ghprbPullId}/${ghprbActualCommit::7}/kic_image_build.txt
 		"
 	fi
 	exit $ec
@@ -101,7 +101,7 @@ if [ "$release" = false ]; then
 	if [ $? -gt 0 ]; then
 		message="Hi ${ghprbPullAuthorLoginMention}, we failed to push the reference to the kicbase to your PR. Please run the following command and push manually.
 
-		sed -i 's|Version = .*|Version = \"${KIC_VERSION}\"|;s|baseImageSHA = .*|baseImageSHA = \"${sha}\"|;s|gcrRepo = .*|gcrRepo = \"${GCR_REPO}\"|;s|dockerhubRepo = .*|dockerhubRepo = \"${DH_REPO}\"|' pkg/drivers/kic/types.go; make generate-docs;
+		sed -i 's|Version = .*|Version = \"${KIC_VERSION}\"|;s|baseImageSHA = .*|baseImageSHA = \"${sha}\"|;s|gcrRepo = .*|gcrRepo = \"${GCR_REPO}\"|;s|dockerhubRepo = .*|dockerhubRepo = \"${DH_REPO}\"|' pkg/drivers/kic/types.go
 		
 		"
 	fi
