@@ -14,14 +14,13 @@ function displayError(message) {
   document.body.appendChild(element);
 }
 
-// Creates a generator that reads the response body one line at a time.
-async function* bodyByLinesIterator(response, updateProgress) {
+// Reads `response` into an array of lines while calling `updateProgress` in between.
+async function getBodyLinesWithProgress(response, updateProgress) {
   const utf8Decoder = new TextDecoder('utf-8');
   const reader = response.body.getReader();
 
-  const re = /\n|\r|\r\n/gm;
+  const lines = [];
   let pendingText = "";
-
   let readerDone = false;
   while (!readerDone) {
     // Read a chunk.
@@ -34,27 +33,22 @@ async function* bodyByLinesIterator(response, updateProgress) {
     updateProgress(chunk.length);
     const decodedChunk = utf8Decoder.decode(chunk);
 
-    let startIndex = 0;
-    let result;
-    // Keep processing until there are no more new lines.
-    while ((result = re.exec(decodedChunk)) !== null) {
-      const text = decodedChunk.substring(startIndex, result.index);
-      startIndex = re.lastIndex;
-
-      const line = pendingText + text;
+    const sublines = decodedChunk.split('\n');
+    for (let i = 0; i < sublines.length - 1; i++) {
+      const fullLine = pendingText + sublines[i];
       pendingText = "";
-      if (line !== "") {
-        yield line;
+      if (fullLine !== "") {
+        lines.push(fullLine);
       }
     }
-    // Any text after the last new line is appended to any pending text.
-    pendingText += decodedChunk.substring(startIndex);
+    pendingText = sublines[sublines.length - 1];
   }
 
-  // If there is any text remaining, return it.
+  // If there is any text remaining, append it.
   if (pendingText !== "") {
-    yield pendingText;
+    lines.push(pendingText);
   }
+  return lines;
 }
 
 // Determines whether `str` matches at least one value in `enumObject`.
@@ -75,12 +69,18 @@ const testStatus = {
 }
 
 async function loadTestData() {
-  const response = await fetch("data.csv");
+  const response = await fetch("data.csv", {
+    headers: {
+      "Cache-Control": "max-age=3600,must-revalidate",
+    }
+  });
   if (!response.ok) {
     const responseText = await response.text();
     throw `Failed to fetch data from GCS bucket. Error: ${responseText}`;
   }
 
+  const responseDate = new Date(response.headers.get("date").toString());
+
   const box = document.createElement("div");
   box.style.width = "100%";
   const innerBox = document.createElement("div");
@@ -98,23 +98,35 @@ async function loadTestData() {
   document.body.appendChild(box);
 
   let readBytes = 0;
-  const lines = bodyByLinesIterator(response, value => {
+  const lines = await getBodyLinesWithProgress(response, value => {
     readBytes += value;
     progressBar.setAttribute("value", readBytes);
   });
   // Consume the header to ensure the data has the right number of fields.
-  const header = (await lines.next()).value;
-  if (header.split(",").length != 6) {
+  const header = lines[0];
+  if (header.split(",").length != 9) {
     document.body.removeChild(box);
-    throw `Fetched CSV data contains wrong number of fields. Expected: 6. Actual Header: "${header}"`;
+    throw `Fetched CSV data contains wrong number of fields. Expected: 9. Actual Header: "${header}"`;
   }
 
+  progressBarPrompt.textContent = "Parsing data...";
+  progressBar.setAttribute("max", lines.length);
+
   const testData = [];
-  let lineData = ["", "", "", "", "", ""];
-  for await (const line of lines) {
+  let lineData = ["", "", "", "", "", "", "", "", ""];
+  for (let i = 1; i < lines.length; i++) {
+    if (i % 30000 === 0) {
+      await new Promise(resolve => {
+        setTimeout(() => {
+          progressBar.setAttribute("value", i);
+          resolve();
+        });
+      });
+    }
+    const line = lines[i];
     let splitLine = line.split(",");
-    if (splitLine.length != 6) {
-      console.warn(`Found line with wrong number of fields. Actual: ${splitLine.length} Expected: 6. Line: "${line}"`);
+    if (splitLine.length != 9) {
+      console.warn(`Found line with wrong number of fields. Actual: ${splitLine.length} Expected: 9. Line: "${line}"`);
       continue;
     }
     splitLine = splitLine.map((value, index) => value === "" ? lineData[index] : value);
@@ -123,6 +135,10 @@ async function loadTestData() {
       console.warn(`Invalid test status provided. Actual: ${splitLine[4]} Expected: One of ${Object.values(testStatus).join(", ")}`);
       continue;
     }
+    // Skip unsafe dates.
+    if (splitLine[1] === "0001-01-01") {
+      continue;
+    }
     testData.push({
       commit: splitLine[0],
       date: new Date(splitLine[1]),
@@ -130,13 +146,24 @@ async function loadTestData() {
       name: splitLine[3],
       status: splitLine[4],
       duration: Number(splitLine[5]),
+      rootJob: splitLine[6],
+      testCount: Number(splitLine[7]),
+      totalDuration: Number(splitLine[8]),
     });
   }
   document.body.removeChild(box);
   if (testData.length == 0) {
     throw "Fetched CSV data is empty or poorly formatted.";
   }
-  return testData;
+  return [testData, responseDate];
+}
+
+Array.prototype.min = function() {
+  return this.reduce((acc, val) => Math.min(acc, val), Number.MAX_VALUE)
+}
+
+Array.prototype.max = function() {
+  return this.reduce((acc, val) => Math.max(acc, val), -Number.MAX_VALUE)
 }
 
 Array.prototype.sum = function() {
@@ -161,6 +188,10 @@ Array.prototype.groupBy = function (keyGetter) {
   }, new Map()).values());
 };
 
+Array.prototype.oneOfEach = function (keyGetter) {
+  return Array.from(new Map(this.map(value => [ keyGetter(value), value ])).values());
+}
+
 // Parse URL search `query` into [{key, value}].
 function parseUrlQuery(query) {
   if (query[0] === '?') {
@@ -184,73 +215,170 @@ function aggregateRuns(testRuns) {
       date: tests[0].date, // Get one of the dates from the tests (which will all be the same).
       flakeRate: tests.map(test => test.status === testStatus.FAILED ? 100 : 0).average(), // Compute average of runs where FAILED counts as 100%.
       duration: tests.map(test => test.duration).average(), // Compute average duration of runs.
-      commitHashes: tests.map(test => ({ // Take all hashes, statuses, and durations of tests in this group.
-        hash: test.commit,
+      jobs: tests.map(test => ({ // Take all job ids, statuses, and durations of tests in this group.
+        id: test.rootJob,
         status: test.status,
         duration: test.duration
-      })).groupBy(run => run.hash).map(runsWithSameHash => ({
-        hash: runsWithSameHash[0].hash,
-        failures: runsWithSameHash.map(run => run.status === testStatus.FAILED ? 1 : 0).sum(),
-        runs: runsWithSameHash.length,
-        duration: runsWithSameHash.map(run => run.duration).average(),
       }))
     }));
 }
 
-const hashToLink = (hash, environment) => `https://storage.googleapis.com/minikube-builds/logs/master/${hash.substring(0,7)}/${environment}.html`;
+// Takes a set of test runs (all of the same test), and aggregates them into one element per week.
+function aggregateWeeklyRuns(testRuns, weekDates) {
+  return testRuns
+    // Group runs by the date it ran.
+    .groupBy(run => weekDates.findRounded(run.date).getTime())
+    // Sort by run date, past to future.
+    .sort((a, b) => weekDates.findRounded(a[0].date) - weekDates.findRounded(b[0].date))
+    // Map each group to all variables need to format the rows.
+    .map(tests => ({
+      date: weekDates.findRounded(tests[0].date), // Get one of the dates from the tests, and use it to get the rounded time (which will all be the same).
+      flakeRate: tests.map(test => test.status === testStatus.FAILED ? 100 : 0).average(), // Compute average of runs where FAILED counts as 100%.
+      duration: tests.map(test => test.duration).average(), // Compute average duration of runs.
+      jobs: tests.map(test => ({ // Take all job ids, statuses, and durations of tests in this group.
+        id: test.rootJob,
+        status: test.status,
+        duration: test.duration
+      }))
+    }));
+}
+
+const testGopoghLink = (jobId, environment, testName) => `https://storage.googleapis.com/minikube-builds/logs/master/${jobId}/${environment}.html${testName ? `#fail_${testName}` : ``}`;
 
 function displayTestAndEnvironmentChart(testData, testName, environmentName) {
-  const data = new google.visualization.DataTable();
-  data.addColumn('date', 'Date');
-  data.addColumn('number', 'Flake Percentage');
-  data.addColumn({ type: 'string', role: 'tooltip', 'p': { 'html': true } });
-  data.addColumn('number', 'Duration');
-  data.addColumn({ type: 'string', role: 'tooltip', 'p': { 'html': true } });
-
   const testRuns = testData
     // Filter to only contain unskipped runs of the requested test and requested environment.
     .filter(test => test.name === testName && test.environment === environmentName && test.status !== testStatus.SKIPPED);
+  const chartsContainer = document.getElementById('chart_div');
+  {
+    const data = new google.visualization.DataTable();
+    data.addColumn('date', 'Date');
+    data.addColumn('number', 'Flake Percentage');
+    data.addColumn({ type: 'string', role: 'tooltip', 'p': { 'html': true } });
+    data.addColumn('number', 'Duration');
+    data.addColumn({ type: 'string', role: 'tooltip', 'p': { 'html': true } });
 
-  data.addRows(
-    aggregateRuns(testRuns)
-      .map(groupData => [
-        groupData.date,
-        groupData.flakeRate,
-        `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
-          <b>${groupData.date.toString()}</b><br>
-          <b>Flake Percentage:</b> ${groupData.flakeRate.toFixed(2)}%<br>
-          <b>Hashes:</b><br>
-          ${groupData.commitHashes.map(({ hash, failures, runs }) => `  - <a href="${hashToLink(hash, environmentName)}">${hash}</a> (Failures: ${failures}/${runs})`).join("<br>")}
-        </div>`,
-        groupData.duration,
-        `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
-          <b>${groupData.date.toString()}</b><br>
-          <b>Average Duration:</b> ${groupData.duration.toFixed(2)}s<br>
-          <b>Hashes:</b><br>
-          ${groupData.commitHashes.map(({ hash, runs, duration }) => `  - <a href="${hashToLink(hash, environmentName)}">${hash}</a> (Average of ${runs}: ${duration.toFixed(2)}s)`).join("<br>")}
-        </div>`,
-      ])
-  );
+    data.addRows(
+      aggregateRuns(testRuns)
+        .map(groupData => [
+          groupData.date,
+          groupData.flakeRate,
+          `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
+            <b>Date:</b> ${groupData.date.toLocaleString([], {dateStyle: 'medium'})}<br>
+            <b>Flake Percentage:</b> ${groupData.flakeRate.toFixed(2)}%<br>
+            <b>Jobs:</b><br>
+            ${groupData.jobs.map(({ id, status }) => `  - <a href="${testGopoghLink(id, environmentName, testName)}">${id}</a> (${status})`).join("<br>")}
+          </div>`,
+          groupData.duration,
+          `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
+            <b>Date:</b> ${groupData.date.toLocaleString([], {dateStyle: 'medium'})}<br>
+            <b>Average Duration:</b> ${groupData.duration.toFixed(2)}s<br>
+            <b>Jobs:</b><br>
+            ${groupData.jobs.map(({ id, duration }) => `  - <a href="${testGopoghLink(id, environmentName, testName)}">${id}</a> (${duration}s)`).join("<br>")}
+          </div>`,
+        ])
+    );
 
-  const options = {
-    title: `Flake rate and duration by day of ${testName} on ${environmentName}`,
-    width: window.innerWidth,
-    height: window.innerHeight,
-    pointSize: 10,
-    pointShape: "circle",
-    series: {
-      0: { targetAxisIndex: 0 },
-      1: { targetAxisIndex: 1 },
-    },
-    vAxes: {
-      0: { title: "Flake rate", minValue: 0, maxValue: 100 },
-      1: { title: "Duration (seconds)" },
-    },
-    colors: ['#dc3912', '#3366cc'],
-    tooltip: { trigger: "selection", isHtml: true }
-  };
-  const chart = new google.visualization.LineChart(document.getElementById('chart_div'));
-  chart.draw(data, options);
+    const options = {
+      title: `Flake rate and duration by day of ${testName} on ${environmentName}`,
+      width: window.innerWidth,
+      height: window.innerHeight,
+      pointSize: 10,
+      pointShape: "circle",
+      series: {
+        0: { targetAxisIndex: 0 },
+        1: { targetAxisIndex: 1 },
+      },
+      vAxes: {
+        0: { title: "Flake rate", minValue: 0, maxValue: 100 },
+        1: { title: "Duration (seconds)" },
+      },
+      colors: ['#dc3912', '#3366cc'],
+      tooltip: { trigger: "selection", isHtml: true }
+    };
+    const flakeRateContainer = document.createElement("div");
+    flakeRateContainer.style.width = "100vw";
+    flakeRateContainer.style.height = "100vh";
+    chartsContainer.appendChild(flakeRateContainer);
+    const chart = new google.visualization.LineChart(flakeRateContainer);
+    chart.draw(data, options);
+  }
+  {
+    const dates = testRuns.map(run => run.date.getTime());
+    const startDate = new Date(dates.min());
+    const endDate = new Date(dates.max());
+  
+    const weekDates = [];
+    let currentDate = startDate;
+    while (currentDate < endDate) {
+      weekDates.push(currentDate);
+      currentDate = new Date(currentDate);
+      currentDate.setDate(currentDate.getDate() + 7);
+    }
+    weekDates.push(currentDate);
+    weekDates.findRounded = function (value) {
+      let index = this.findIndex(v => value < v);
+      if (index == 0) {
+        return this[index];
+      }
+      if (index < 0) {
+        index = this.length;
+      }
+      return this[index - 1];
+    }
+
+    const data = new google.visualization.DataTable();
+    data.addColumn('date', 'Date');
+    data.addColumn('number', 'Flake Percentage');
+    data.addColumn({ type: 'string', role: 'tooltip', 'p': { 'html': true } });
+    data.addColumn('number', 'Duration');
+    data.addColumn({ type: 'string', role: 'tooltip', 'p': { 'html': true } });
+
+    data.addRows(
+      aggregateWeeklyRuns(testRuns, weekDates)
+        .map(groupData => [
+          groupData.date,
+          groupData.flakeRate,
+          `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
+            <b>Date:</b> ${groupData.date.toLocaleString([], {dateStyle: 'medium'})}<br>
+            <b>Flake Percentage:</b> ${groupData.flakeRate.toFixed(2)}%<br>
+            <b>Jobs:</b><br>
+            ${groupData.jobs.map(({ id, status }) => `  - <a href="${testGopoghLink(id, environmentName, testName)}">${id}</a> (${status})`).join("<br>")}
+          </div>`,
+          groupData.duration,
+          `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
+            <b>Date:</b> ${groupData.date.toLocaleString([], {dateStyle: 'medium'})}<br>
+            <b>Average Duration:</b> ${groupData.duration.toFixed(2)}s<br>
+            <b>Jobs:</b><br>
+            ${groupData.jobs.map(({ id, duration }) => `  - <a href="${testGopoghLink(id, environmentName, testName)}">${id}</a> (${duration}s)`).join("<br>")}
+          </div>`,
+        ])
+    );
+
+    const options = {
+      title: `Flake rate and duration by week of ${testName} on ${environmentName}`,
+      width: window.innerWidth,
+      height: window.innerHeight,
+      pointSize: 10,
+      pointShape: "circle",
+      series: {
+        0: { targetAxisIndex: 0 },
+        1: { targetAxisIndex: 1 },
+      },
+      vAxes: {
+        0: { title: "Flake rate", minValue: 0, maxValue: 100 },
+        1: { title: "Duration (seconds)" },
+      },
+      colors: ['#dc3912', '#3366cc'],
+      tooltip: { trigger: "selection", isHtml: true }
+    };
+    const flakeRateContainer = document.createElement("div");
+    flakeRateContainer.style.width = "100vw";
+    flakeRateContainer.style.height = "100vh";
+    chartsContainer.appendChild(flakeRateContainer);
+    const chart = new google.visualization.LineChart(flakeRateContainer);
+    chart.draw(data, options);
+  }
 }
 
 function createRecentFlakePercentageTable(recentFlakePercentage, previousFlakePercentageMap, environmentName) {
@@ -267,6 +395,7 @@ function createRecentFlakePercentageTable(recentFlakePercentage, previousFlakePe
   tableHeaderRow.appendChild(createCell("th", "Recent Flake Percentage"));
   tableHeaderRow.appendChild(createCell("th", "Growth (since last 15 days)"));
   table.appendChild(tableHeaderRow);
+  const tableBody = document.createElement("tbody");
   for (let i = 0; i < recentFlakePercentage.length; i++) {
     const {testName, flakeRate} = recentFlakePercentage[i];
     const row = document.createElement("tr");
@@ -276,8 +405,10 @@ function createRecentFlakePercentageTable(recentFlakePercentage, previousFlakePe
     const growth = previousFlakePercentageMap.has(testName) ?
       flakeRate - previousFlakePercentageMap.get(testName) : 0;
     row.appendChild(createCell("td", `<span style="color: ${growth === 0 ? "black" : (growth > 0 ? "red" : "green")}">${growth > 0 ? '+' + growth.toFixed(2) : growth.toFixed(2)}%</span>`));
-    table.appendChild(row);
+    tableBody.appendChild(row);
   }
+  table.appendChild(tableBody);
+  new Tablesort(table);
   return table;
 }
 
@@ -313,7 +444,7 @@ function displayEnvironmentChart(testData, environmentName) {
       const dateInfo = data.get(date);
       return dateInfo === undefined ? null : {
         flakeRate: dateInfo.flakeRate,
-        runs: dateInfo.commitHashes.length
+        runs: dateInfo.jobs.length
       };
     }).filter(dateInfo => dateInfo != null)
       .reduce(({flakeCount, totalCount}, {flakeRate, runs}) => ({
@@ -351,10 +482,10 @@ function displayEnvironmentChart(testData, environmentName) {
           data.flakeRate,
           `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
             <b style="display: block">${name}</b><br>
-            <b>${data.date.toString()}</b><br>
+            <b>Date:</b> ${data.date.toLocaleString([], {dateStyle: 'medium'})}<br>
             <b>Flake Percentage:</b> ${data.flakeRate.toFixed(2)}%<br>
-            <b>Hashes:</b><br>
-            ${data.commitHashes.map(({ hash, failures, runs }) => `  - <a href="${hashToLink(hash, environmentName)}">${hash}</a> (Failures: ${failures}/${runs})`).join("<br>")}
+            <b>Jobs:</b><br>
+            ${data.jobs.map(({ id, status }) => `  - <a href="${testGopoghLink(id, environmentName, name)}">${id}</a> (${status})`).join("<br>")}
           </div>`
         ] : [null, null];
       })).flat())
@@ -378,116 +509,142 @@ function displayEnvironmentChart(testData, environmentName) {
     chart.draw(data, options);
   }
   {
+    const dates = testData.map(run => run.date.getTime());
+    const startDate = new Date(dates.min());
+    const endDate = new Date(dates.max());
+  
+    const weekDates = [];
+    let currentDate = startDate;
+    while (currentDate < endDate) {
+      weekDates.push(currentDate);
+      currentDate = new Date(currentDate);
+      currentDate.setDate(currentDate.getDate() + 7);
+    }
+    weekDates.push(currentDate);
+    weekDates.findRounded = function (value) {
+      let index = this.findIndex(v => value < v);
+      if (index == 0) {
+        return this[index];
+      }
+      if (index < 0) {
+        index = this.length;
+      }
+      return this[index - 1];
+    }
+    const aggregatedWeeklyRuns = new Map(testRuns.map(test => [
+      test[0].name,
+      new Map(aggregateWeeklyRuns(test, weekDates)
+        .map(runDate => [ weekDates.findRounded(runDate.date).getTime(), runDate ]))]));
+    const uniqueWeekDates = new Set();
+    for (const [_, runDateMap] of aggregatedWeeklyRuns) {
+      for (const [dateTime, _] of runDateMap) {
+        uniqueWeekDates.add(dateTime);
+      }
+    }
+    const orderedWeekDates = Array.from(uniqueWeekDates).sort();
+    const recentWeeklyTopFlakes = computeFlakePercentage(aggregatedWeeklyRuns, [orderedWeekDates[orderedWeekDates.length - 1]])
+      .sort((a, b) => b.flakeRate - a.flakeRate)
+      .slice(0, topFlakes)
+      .map(({testName}) => testName);
     const data = new google.visualization.DataTable();
     data.addColumn('date', 'Date');
-    for (const name of recentTopFlakes) {
-      data.addColumn('number', `Duration - ${name}`);
+    for (const name of recentWeeklyTopFlakes) {
+      data.addColumn('number', `Flake Percentage - ${name}`);
       data.addColumn({ type: 'string', role: 'tooltip', 'p': { 'html': true } });
     }
     data.addRows(
-      orderedDates.map(dateTime => [new Date(dateTime)].concat(recentTopFlakes.map(name => {
-        const data = aggregatedRuns.get(name).get(dateTime);
+      orderedWeekDates.map(dateTime => [new Date(dateTime)].concat(recentTopFlakes.map(name => {
+        const data = aggregatedWeeklyRuns.get(name).get(dateTime);
         return data !== undefined ? [
-          data.duration,
+          data.flakeRate,
           `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
             <b style="display: block">${name}</b><br>
-            <b>${data.date.toString()}</b><br>
-            <b>Average Duration:</b> ${data.duration.toFixed(2)}s<br>
-            <b>Hashes:</b><br>
-            ${data.commitHashes.map(({ hash, duration, runs }) => `  - <a href="${hashToLink(hash, environmentName)}">${hash}</a> (Average Duration: ${duration.toFixed(2)}s [${runs} runs])`).join("<br>")}
+            <b>Date:</b> ${data.date.toLocaleString([], {dateStyle: 'medium'})}<br>
+            <b>Flake Percentage:</b> ${data.flakeRate.toFixed(2)}%<br>
+            <b>Jobs:</b><br>
+            ${data.jobs.map(({ id, status }) => `  - <a href="${testGopoghLink(id, environmentName, name)}">${id}</a> (${status})`).join("<br>")}
           </div>`
         ] : [null, null];
       })).flat())
     );
     const options = {
-      title: `Average duration by day of top ${topFlakes} of recent test flakiness (past ${dateRange} days) on ${environmentName}`,
+      title: `Flake rate by week of top ${topFlakes} of recent test flakiness (past week) on ${environmentName}`,
       width: window.innerWidth,
       height: window.innerHeight,
       pointSize: 10,
       pointShape: "circle",
       vAxes: {
-        0: { title: "Average Duration (s)" },
+        0: { title: "Flake rate", minValue: 0, maxValue: 100 },
       },
       tooltip: { trigger: "selection", isHtml: true }
     };
-    const durationContainer = document.createElement("div");
-    durationContainer.style.width = "100vw";
-    durationContainer.style.height = "100vh";
-    chartsContainer.appendChild(durationContainer);
-    const chart = new google.visualization.LineChart(durationContainer);
+    const flakeRateContainer = document.createElement("div");
+    flakeRateContainer.style.width = "100vw";
+    flakeRateContainer.style.height = "100vh";
+    chartsContainer.appendChild(flakeRateContainer);
+    const chart = new google.visualization.LineChart(flakeRateContainer);
     chart.draw(data, options);
   }
   {
-    // Group test runs by their date, then by their commit, and finally by test names.
-    const testCountData = testData
-      // Group by date.
-      .groupBy(run => run.date.getTime())
-      .map(runDate => ({
-        date: runDate[0].date,
-        commits: runDate
-          // Group by commit
-          .groupBy(run => run.commit)
-          .map(commitRuns => commitRuns
-            // Group by test name.
-            .groupBy(commitRun => commitRun.name)
-            // Consolidate tests of a single name into a single object.
-            .reduce((accum, commitTestRuns) => ({
-              commit: commitTestRuns[0].commit,
-              // The total number of times any test ran.
-              sumTestCount: accum.sumTestCount + commitTestRuns.length,
-              // The total number of times any test failed.
-              sumFailCount: accum.sumFailCount + commitTestRuns.filter(run => run.status === testStatus.FAILED).length,
-              // The most number of times any test name ran (this will be a proxy for the number of integration jobs were triggered).
-              maxRunCount: Math.max(accum.maxRunCount, commitTestRuns.length),
-            }), {
-              sumTestCount: 0,
-              sumFailCount: 0,
-              maxRunCount: 0
+    const jobData = 
+      testData
+        .groupBy(run => run.date.getTime())
+        .map(runDate => ({
+          date: runDate[0].date,
+          runInfo: runDate
+            .oneOfEach(run => run.rootJob)
+            .map(run => ({
+              commit: run.commit,
+              rootJob: run.rootJob,
+              testCount: run.testCount,
+              totalDuration: run.totalDuration
             }))
-      }))
-      .map(dateInfo => ({
-        ...dateInfo,
-        // Use the commit data of each date to compute the average test count and average fail count for the day.
-        testCount: dateInfo.commits.reduce(
-          (accum, commitInfo) => accum + (commitInfo.sumTestCount / commitInfo.maxRunCount), 0) / dateInfo.commits.length,
-        failCount: dateInfo.commits.reduce(
-          (accum, commitInfo) => accum + (commitInfo.sumFailCount / commitInfo.maxRunCount), 0) / dateInfo.commits.length,
-      }))
-      .sort((a, b) => a.date - b.date);
+        }))
+        .sort((a, b) => a.date - b.date)
+        .map(({date, runInfo}) => ({
+          date,
+          runInfo,
+          testCount: runInfo.map(job => job.testCount).average(),
+          totalDuration: runInfo.map(job => job.totalDuration).average(),
+        }));
 
     const data = new google.visualization.DataTable();
     data.addColumn('date', 'Date');
     data.addColumn('number', 'Test Count');
     data.addColumn({ type: 'string', role: 'tooltip', 'p': { 'html': true } });
-    data.addColumn('number', 'Failed Tests');
+    data.addColumn('number', 'Duration');
     data.addColumn({ type: 'string', role: 'tooltip', 'p': { 'html': true } });
     data.addRows(
-      testCountData.map(dateInfo => [
+      jobData.map(dateInfo => [
         dateInfo.date,
         dateInfo.testCount,
         `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
-          <b>${dateInfo.date.toString()}</b><br>
+          <b>Date:</b> ${dateInfo.date.toLocaleString([], {dateStyle: 'medium'})}<br>
           <b>Test Count (averaged): </b> ${+dateInfo.testCount.toFixed(2)}<br>
-          <b>Hashes:</b><br>
-          ${dateInfo.commits.map(commit => `  - <a href="${hashToLink(commit.commit, environmentName)}">${commit.commit}</a> (Test count (averaged): ${+(commit.sumTestCount / commit.maxRunCount).toFixed(2)} [${commit.sumTestCount} tests / ${commit.maxRunCount} runs])`).join("<br>")}
+          <b>Jobs:</b><br>
+          ${dateInfo.runInfo.map(job => `  - <a href="${testGopoghLink(job.rootJob, environmentName)}">${job.rootJob}</a> Test count: ${job.testCount}`).join("<br>")}
         </div>`,
-        dateInfo.failCount,
+        dateInfo.totalDuration,
         `<div style="padding: 1rem; font-family: 'Arial'; font-size: 14">
-          <b>${dateInfo.date.toString()}</b><br>
-          <b>Fail Count (averaged): </b> ${+dateInfo.failCount.toFixed(2)}<br>
-          <b>Hashes:</b><br>
-          ${dateInfo.commits.map(commit => `  - <a href="${hashToLink(commit.commit, environmentName)}">${commit.commit}</a> (Fail count (averaged): ${+(commit.sumFailCount / commit.maxRunCount).toFixed(2)} [${commit.sumFailCount} fails / ${commit.maxRunCount} runs])`).join("<br>")}
+          <b>Date:</b> ${dateInfo.date.toLocaleString([], {dateStyle: 'medium'})}<br>
+          <b>Total Duration (averaged): </b> ${+dateInfo.totalDuration.toFixed(2)}<br>
+          <b>Jobs:</b><br>
+          ${dateInfo.runInfo.map(job => `  - <a href="${testGopoghLink(job.rootJob, environmentName)}">${job.rootJob}</a> Total Duration: ${+job.totalDuration.toFixed(2)}s`).join("<br>")}
         </div>`,
       ]));
     const options = {
-      title: `Test count by day on ${environmentName}`,
+      title: `Test count and total duration by day on ${environmentName}`,
       width: window.innerWidth,
       height: window.innerHeight,
       pointSize: 10,
       pointShape: "circle",
+      series: {
+        0: { targetAxisIndex: 0 },
+        1: { targetAxisIndex: 1 },
+      },
       vAxes: {
-        0: { title: "Test Count" },
-        1: { title: "Failed Tests" },
+        0: { title: "Test Count", minValue: 0 },
+        1: { title: "Duration (seconds)", minValue: 0 },
       },
       tooltip: { trigger: "selection", isHtml: true }
     };
@@ -499,16 +656,20 @@ function displayEnvironmentChart(testData, environmentName) {
     chart.draw(data, options);
   }
 
-  document.body.appendChild(createRecentFlakePercentageTable(recentFlakePercentage, previousFlakePercentageMap, environmentName));
+  chartsContainer.appendChild(
+    createRecentFlakePercentageTable(
+      recentFlakePercentage,
+      previousFlakePercentageMap,
+      environmentName));
 }
 
 async function init() {
   google.charts.load('current', { 'packages': ['corechart'] });
-  let testData;
+  let testData, responseDate;
   try {
     // Wait for Google Charts to load, and for test data to load.
     // Only store the test data (at index 1) into `testData`.
-    testData = (await Promise.all([
+    [testData, responseDate] = (await Promise.all([
       new Promise(resolve => google.charts.setOnLoadCallback(resolve)),
       loadTestData()
     ]))[1];
@@ -525,6 +686,8 @@ async function init() {
   } else {
     displayTestAndEnvironmentChart(testData, desiredTest, desiredEnvironment);
   }
+  document.querySelector('#data_date_container').style.display = 'block';
+  document.querySelector('#data_date').innerText = responseDate.toLocaleString();
 }
 
 init();
