@@ -64,6 +64,7 @@ type Driver struct {
 	UUID           string
 	VpnKitSock     string
 	VSockPorts     []string
+	ExtraDisks     int
 }
 
 // NewDriver creates a new driver for a host
@@ -229,6 +230,13 @@ func (d *Driver) createHost() (*hyperkit.HyperKit, error) {
 			Trim: true,
 		},
 	}
+	for i := 0; i < d.ExtraDisks; i++ {
+		h.Disks = append(h.Disks, &hyperkit.RawDisk{
+			Path: pkgdrivers.ExtraDiskPath(d.BaseDriver, i),
+			Size: d.DiskSize,
+			Trim: true,
+		})
+	}
 
 	return h, nil
 }
@@ -268,10 +276,7 @@ func (d *Driver) Start() error {
 		return err
 	}
 
-	if err := d.setupNFSMounts(); err != nil {
-		return err
-	}
-	return nil
+	return d.setupNFSMounts()
 }
 
 func (d *Driver) setupIP(mac string) error {
