@@ -24,6 +24,7 @@ import (
 	"io"
 	"os"
 	"path"
+	"strconv"
 	"time"
 
 	"github.com/pkg/errors"
@@ -37,8 +38,11 @@ const MemorySource = "memory"
 // CopyableFile is something that can be copied
 type CopyableFile interface {
 	io.Reader
+	io.Writer
 	GetLength() int
+	SetLength(int)
 	GetSourcePath() string
+	GetTargetPath() string
 
 	GetTargetDir() string
 	GetTargetName() string
@@ -62,6 +66,11 @@ func (b *BaseAsset) GetSourcePath() string {
 	return b.SourcePath
 }
 
+// GetTargetPath returns target path
+func (b *BaseAsset) GetTargetPath() string {
+	return path.Join(b.GetTargetDir(), b.GetTargetName())
+}
+
 // GetTargetDir returns target dir
 func (b *BaseAsset) GetTargetDir() string {
 	return b.TargetDir
@@ -86,6 +95,7 @@ func (b *BaseAsset) GetModTime() (time.Time, error) {
 type FileAsset struct {
 	BaseAsset
 	reader io.ReadSeeker
+	writer io.Writer
 	file   *os.File // Optional pointer to close file through FileAsset.Close()
 }
 
@@ -134,6 +144,14 @@ func (f *FileAsset) GetLength() (flen int) {
 	return int(fi.Size())
 }
 
+// SetLength sets the file length
+func (f *FileAsset) SetLength(flen int) {
+	err := os.Truncate(f.SourcePath, int64(flen))
+	if err != nil {
+		klog.Errorf("truncate(%q) failed: %v", f.SourcePath, err)
+	}
+}
+
 // GetModTime returns modification time of the file
 func (f *FileAsset) GetModTime() (time.Time, error) {
 	fi, err := os.Stat(f.SourcePath)
@@ -152,6 +170,23 @@ func (f *FileAsset) Read(p []byte) (int, error) {
 	return f.reader.Read(p)
 }
 
+// Write writes the asset
+func (f *FileAsset) Write(p []byte) (int, error) {
+	if f.writer == nil {
+		f.file.Close()
+		perms, err := strconv.ParseUint(f.Permissions, 8, 32)
+		if err != nil || perms > 07777 {
+			return 0, err
+		}
+		f.file, err = os.OpenFile(f.SourcePath, os.O_RDWR|os.O_CREATE, os.FileMode(perms))
+		if err != nil {
+			return 0, err
+		}
+		f.writer = io.Writer(f.file)
+	}
+	return f.writer.Write(p)
+}
+
 // Seek resets the reader to offset
 func (f *FileAsset) Seek(offset int64, whence int) (int64, error) {
 	return f.reader.Seek(offset, whence)
@@ -177,11 +212,23 @@ func (m *MemoryAsset) GetLength() int {
 	return m.length
 }
 
+// SetLength returns length
+func (m *MemoryAsset) SetLength(len int) {
+	m.length = len
+}
+
 // Read reads the asset
 func (m *MemoryAsset) Read(p []byte) (int, error) {
 	return m.reader.Read(p)
 }
 
+// Writer writes the asset
+func (m *MemoryAsset) Write(p []byte) (int, error) {
+	m.length = len(p)
+	m.reader = bytes.NewReader(p)
+	return len(p), nil
+}
+
 // Seek resets the reader to offset
 func (m *MemoryAsset) Seek(offset int64, whence int) (int64, error) {
 	return m.reader.Seek(offset, whence)
@@ -298,6 +345,11 @@ func (m *BinAsset) GetLength() int {
 	return m.length
 }
 
+// SetLength sets length
+func (m *BinAsset) SetLength(len int) {
+	m.length = len
+}
+
 // Read reads the asset
 func (m *BinAsset) Read(p []byte) (int, error) {
 	if m.GetLength() == 0 {
@@ -306,6 +358,13 @@ func (m *BinAsset) Read(p []byte) (int, error) {
 	return m.reader.Read(p)
 }
 
+// Write writes the asset
+func (m *BinAsset) Write(p []byte) (int, error) {
+	m.length = len(p)
+	m.reader = bytes.NewReader(p)
+	return len(p), nil
+}
+
 // Seek resets the reader to offset
 func (m *BinAsset) Seek(offset int64, whence int) (int64, error) {
 	return m.reader.Seek(offset, whence)
