@@ -65,6 +65,15 @@ k8s.gcr.io/kube-proxy:v1.21.0
 k8s.gcr.io/pause:3.4.1
 k8s.gcr.io/etcd:3.4.13-0
 k8s.gcr.io/coredns/coredns:v1.8.0
+`, "\n"), "\n")},
+		{"v1.22.0", strings.Split(strings.Trim(`
+k8s.gcr.io/kube-apiserver:v1.22.0
+k8s.gcr.io/kube-controller-manager:v1.22.0
+k8s.gcr.io/kube-scheduler:v1.22.0
+k8s.gcr.io/kube-proxy:v1.22.0
+k8s.gcr.io/pause:3.5
+k8s.gcr.io/etcd:3.5.0-0
+k8s.gcr.io/coredns/coredns:v1.8.4
 `, "\n"), "\n")},
 	}
 	for _, tc := range testCases {
@@ -96,9 +105,9 @@ func TestAuxiliary(t *testing.T) {
 
 func TestAuxiliaryMirror(t *testing.T) {
 	want := []string{
-		"test.mirror/storage-provisioner:" + version.GetStorageProvisionerVersion(),
-		"test.mirror/dashboard:v2.1.0",
-		"test.mirror/metrics-scraper:v1.0.4",
+		"test.mirror/k8s-minikube/storage-provisioner:" + version.GetStorageProvisionerVersion(),
+		"test.mirror/kubernetesui/dashboard:v2.1.0",
+		"test.mirror/kubernetesui/metrics-scraper:v1.0.4",
 	}
 	got := auxiliary("test.mirror")
 	if diff := cmp.Diff(want, got); diff != "" {
