@@ -75,6 +75,9 @@ type Runner interface {
 	// Copy is a convenience method that runs a command to copy a file
 	Copy(assets.CopyableFile) error
 
+	// CopyFrom is a convenience method that runs a command to copy a file back
+	CopyFrom(assets.CopyableFile) error
+
 	// Remove is a convenience method that runs a command to remove a file
 	Remove(assets.CopyableFile) error
 }
