@@ -26,6 +26,7 @@ import (
 	"github.com/pkg/errors"
 	"github.com/spf13/viper"
 
+	"k8s.io/klog/v2"
 	"k8s.io/minikube/pkg/minikube/localpath"
 )
 
@@ -38,6 +39,8 @@ const (
 	ReminderWaitPeriodInHours = "ReminderWaitPeriodInHours"
 	// WantNoneDriverWarning is the key for WantNoneDriverWarning
 	WantNoneDriverWarning = "WantNoneDriverWarning"
+	// WantVirtualBoxDriverWarning is the key for WantVirtualBoxDriverWarning
+	WantVirtualBoxDriverWarning = "WantVirtualBoxDriverWarning"
 	// ProfileName represents the key for the global profile parameter
 	ProfileName = "profile"
 	// UserFlag is the key for the global user flag (ex. --user=user1)
@@ -169,7 +172,15 @@ func encode(w io.Writer, m MinikubeConfig) error {
 
 // Load loads the Kubernetes and machine config for the current machine
 func Load(profile string, miniHome ...string) (*ClusterConfig, error) {
-	return DefaultLoader.LoadConfigFromFile(profile, miniHome...)
+	cc, err := DefaultLoader.LoadConfigFromFile(profile, miniHome...)
+	if err == nil {
+		klog.Infof("Loaded profile config \"%s\": Driver=%s, ContainerRuntime=%s, KubernetesVersion=%s",
+			profile,
+			cc.Driver,
+			cc.KubernetesConfig.ContainerRuntime,
+			cc.KubernetesConfig.KubernetesVersion)
+	}
+	return cc, err
 }
 
 // Write writes the Kubernetes and machine config for the current machine
