@@ -175,6 +175,37 @@ var hostIssues = []match{
 		},
 		Regexp: re(`Container.*is not running.*chown docker:docker`),
 	},
+	{
+		Kind: Kind{
+			ID:       "HOST_CGROUP_NOT_SUPPORTED",
+			ExitCode: ExHostUnsupported,
+			Advice: `CGroup allocation is not available in your environment. You might be running minikube in a nested container. Try running:
+			
+	minikube start --extra-config=kubelet.cgroups-per-qos=false --extra-config=kubelet.enforce-node-allocatable=""
+
+			
+			`,
+			Issues: []int{12232},
+		},
+		Regexp: re(`Failed to start ContainerManager" err="Unit kubepods.slice already exists.`),
+		GOOS:   []string{"linux"},
+	},
+	{
+		Kind: Kind{
+			ID:       "HOST_ROOT_CGROUP",
+			ExitCode: ExHostUnsupported,
+			Advice: `CGroup allocation is not available in your environment, You might be running minikube in a nested container. Try running:
+			
+	minikube start --extra-config=kubelet.cgroups-per-qos=false --extra-config=kubelet.enforce-node-allocatable=""
+
+			
+			`,
+			Issues: []int{12232},
+		},
+		Regexp: re(`Failed to start ContainerManager" err="failed to initialize top level QOS containers: root container [kubepods] doesn't exist`),
+		GOOS:   []string{"linux"},
+	},
+
 	{
 		Kind: Kind{
 			ID:       "HOST_PIDS_CGROUP",
@@ -1162,6 +1193,16 @@ var controlPlaneIssues = []match{
 		},
 		Regexp: re(`apiServer.certSANs: Invalid value`),
 	},
+	{
+		Kind: Kind{
+			ID:           "K8S_UNHEALTHY_CONTROL_PLANE",
+			ExitCode:     ExControlPlaneTimeout,
+			Advice:       "Control Plane could not update, try minikube delete --all --purge",
+			NewIssueLink: true,
+			Issues:       []int{11417},
+		},
+		Regexp: re(`controlPlane never updated to`),
+	},
 }
 
 // serviceIssues are issues with services running on top of Kubernetes
