@@ -315,12 +315,29 @@ var (
 	GuestImageLoad = Kind{ID: "GUEST_IMAGE_LOAD", ExitCode: ExGuestError}
 	// minikube failed to remove an image
 	GuestImageRemove = Kind{ID: "GUEST_IMAGE_REMOVE", ExitCode: ExGuestError}
+	// minikube failed to pull an image
+	GuestImagePull = Kind{ID: "GUEST_IMAGE_PULL", ExitCode: ExGuestError}
 	// minikube failed to build an image
 	GuestImageBuild = Kind{ID: "GUEST_IMAGE_BUILD", ExitCode: ExGuestError}
+	// minikube failed to push or save an image
+	GuestImageSave = Kind{ID: "GUEST_IMAGE_SAVE", ExitCode: ExGuestError}
+	// minikube failed to push an image
+	GuestImagePush = Kind{ID: "GUEST_IMAGE_PUSH", ExitCode: ExGuestError}
+	// minikube failed to tag an image
+	GuestImageTag = Kind{ID: "GUEST_IMAGE_TAG", ExitCode: ExGuestError}
 	// minikube failed to load host
 	GuestLoadHost = Kind{ID: "GUEST_LOAD_HOST", ExitCode: ExGuestError}
 	// minkube failed to create a mount
 	GuestMount = Kind{ID: "GUEST_MOUNT", ExitCode: ExGuestError}
+	// mount on guest was unable to connect to host mount server
+	GuestMountCouldNotConnect = Kind{
+		ID:       "GUEST_MOUNT_COULD_NOT_CONNECT",
+		ExitCode: ExGuestError,
+		Advice: `If the host has a firewall:
+		
+		1. Allow a port through the firewall
+		2. Specify "--port=<port_number>" for "minikube mount"`,
+	}
 	// minkube failed to update a mount
 	GuestMountConflict = Kind{ID: "GUEST_MOUNT_CONFLICT", ExitCode: ExGuestConflict}
 	// minikube failed to add a node to the cluster
