@@ -99,6 +99,8 @@ func TestFunctional(t *testing.T) {
 			{"MinikubeKubectlCmdDirectly", validateMinikubeKubectlDirectCall},
 			{"ExtraConfig", validateExtraConfig}, // Ensure extra cmdline config change is saved
 			{"ComponentHealth", validateComponentHealth},
+			{"LogsCmd", validateLogsCmd},
+			{"LogsFileCmd", validateLogsFileCmd},
 		}
 		for _, tc := range tests {
 			tc := tc
@@ -133,8 +135,6 @@ func TestFunctional(t *testing.T) {
 			{"DryRun", validateDryRun},
 			{"InternationalLanguage", validateInternationalLanguage},
 			{"StatusCmd", validateStatusCmd},
-			{"LogsCmd", validateLogsCmd},
-			{"LogsFileCmd", validateLogsFileCmd},
 			{"MountCmd", validateMountCmd},
 			{"ProfileCmd", validateProfileCmd},
 			{"ServiceCmd", validateServiceCmd},
@@ -151,7 +151,10 @@ func TestFunctional(t *testing.T) {
 			{"PodmanEnv", validatePodmanEnv},
 			{"NodeLabels", validateNodeLabels},
 			{"LoadImage", validateLoadImage},
+			{"SaveImage", validateSaveImage},
 			{"RemoveImage", validateRemoveImage},
+			{"LoadImageFromFile", validateLoadImageFromFile},
+			{"SaveImageToFile", validateSaveImageToFile},
 			{"BuildImage", validateBuildImage},
 			{"ListImages", validateListImages},
 			{"NonActiveRuntimeDisabled", validateNotActiveRuntimeDisabled},
@@ -205,7 +208,6 @@ func cleanupUnwantedImages(ctx context.Context, t *testing.T, profile string) {
 			}
 		})
 	}
-
 }
 
 // validateNodeLabels checks if minikube cluster is created with correct kubernetes's node label
@@ -248,7 +250,7 @@ func validateLoadImage(ctx context.Context, t *testing.T, profile string) {
 	}
 
 	// try to load the new image into minikube
-	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", newImage))
+	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", "--daemon", newImage))
 	if err != nil {
 		t.Fatalf("loading image into minikube: %v\n%s", err, rr.Output())
 	}
@@ -264,6 +266,57 @@ func validateLoadImage(ctx context.Context, t *testing.T, profile string) {
 
 }
 
+// validateLoadImageFromFile makes sure that `minikube image load` works from a local file
+func validateLoadImageFromFile(ctx context.Context, t *testing.T, profile string) {
+	if NoneDriver() {
+		t.Skip("load image not available on none driver")
+	}
+	if GithubActionRunner() && runtime.GOOS == "darwin" {
+		t.Skip("skipping on github actions and darwin, as this test requires a running docker daemon")
+	}
+	defer PostMortemLogs(t, profile)
+	// pull busybox
+	busyboxImage := "busybox:1.31"
+	rr, err := Run(t, exec.CommandContext(ctx, "docker", "pull", busyboxImage))
+	if err != nil {
+		t.Fatalf("failed to setup test (pull image): %v\n%s", err, rr.Output())
+	}
+
+	tag := fmt.Sprintf("load-from-file-%s", profile)
+	taggedImage := fmt.Sprintf("docker.io/library/busybox:%s", tag)
+	rr, err = Run(t, exec.CommandContext(ctx, "docker", "tag", busyboxImage, taggedImage))
+	if err != nil {
+		t.Fatalf("failed to setup test (tag image) : %v\n%s", err, rr.Output())
+	}
+
+	// save image to file
+	imageFile := "busybox-load.tar"
+	rr, err = Run(t, exec.CommandContext(ctx, "docker", "save", "-o", imageFile, taggedImage))
+	if err != nil {
+		t.Fatalf("failed to save image to file: %v\n%s", err, rr.Output())
+	}
+	defer os.Remove(imageFile)
+
+	// try to load the new image into minikube
+	imagePath, err := filepath.Abs(imageFile)
+	if err != nil {
+		t.Fatalf("failed to get absolute path of file %q: %v", imageFile, err)
+	}
+	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", imagePath))
+	if err != nil || rr.Stderr.String() != "" {
+		t.Fatalf("loading image into minikube: %v\n%s", err, rr.Output())
+	}
+
+	// make sure the image was correctly loaded
+	rr, err = listImages(ctx, t, profile)
+	if err != nil {
+		t.Fatalf("listing images: %v\n%s", err, rr.Output())
+	}
+	if !strings.Contains(rr.Output(), tag) {
+		t.Fatalf("expected %s to be loaded into minikube but the image is not there: %v", taggedImage, rr.Output())
+	}
+}
+
 // validateRemoveImage makes sures that `minikube image rm` works as expected
 func validateRemoveImage(ctx context.Context, t *testing.T, profile string) {
 	if NoneDriver() {
@@ -311,6 +364,101 @@ func validateRemoveImage(ctx context.Context, t *testing.T, profile string) {
 
 }
 
+// validateSaveImage makes sure that `minikube image save` works as expected
+func validateSaveImage(ctx context.Context, t *testing.T, profile string) {
+	if NoneDriver() {
+		t.Skip("load image not available on none driver")
+	}
+	if GithubActionRunner() && runtime.GOOS == "darwin" {
+		t.Skip("skipping on github actions and darwin, as this test requires a running docker daemon")
+	}
+	defer PostMortemLogs(t, profile)
+	// pull busybox
+	busyboxImage := "docker.io/library/busybox:1.29"
+	rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "pull", busyboxImage))
+	if err != nil {
+		t.Fatalf("failed to setup test (pull image): %v\n%s", err, rr.Output())
+	}
+
+	// tag busybox
+	name := "busybox"
+	tag := fmt.Sprintf("save-%s", profile)
+	newImage := fmt.Sprintf("docker.io/library/%s:%s", name, tag)
+	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "tag", busyboxImage, newImage))
+	if err != nil {
+		t.Fatalf("failed to setup test (tag image) : %v\n%s", err, rr.Output())
+	}
+
+	// try to save the new image from minikube
+	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "save", "--daemon", newImage))
+	if err != nil {
+		t.Fatalf("loading image into minikube: %v\n%s", err, rr.Output())
+	}
+
+	// make sure the image was correctly loaded
+	rr, err = Run(t, exec.CommandContext(ctx, "docker", "images", name))
+	if err != nil {
+		t.Fatalf("listing images: %v\n%s", err, rr.Output())
+	}
+	if !strings.Contains(rr.Output(), fmt.Sprintf("save-%s", profile)) {
+		t.Fatalf("expected %s to be loaded into minikube but the image is not there", newImage)
+	}
+
+}
+
+// validateSaveImageToFile makes sure that `minikube image save` works to a local file
+func validateSaveImageToFile(ctx context.Context, t *testing.T, profile string) {
+	if NoneDriver() {
+		t.Skip("save image not available on none driver")
+	}
+	if GithubActionRunner() && runtime.GOOS == "darwin" {
+		t.Skip("skipping on github actions and darwin, as this test requires a running docker daemon")
+	}
+	defer PostMortemLogs(t, profile)
+	// pull busybox
+	busyboxImage := "docker.io/library/busybox:1.30"
+	rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "pull", busyboxImage))
+	if err != nil {
+		t.Fatalf("failed to setup test (pull image): %v\n%s", err, rr.Output())
+	}
+
+	name := "busybox"
+	tag := fmt.Sprintf("save-to-file-%s", profile)
+	taggedImage := fmt.Sprintf("docker.io/library/%s:%s", name, tag)
+	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "tag", busyboxImage, taggedImage))
+	if err != nil {
+		t.Fatalf("failed to setup test (tag image) : %v\n%s", err, rr.Output())
+	}
+
+	// try to save the new image from minikube
+	imageFile := "busybox-save.tar"
+	imagePath, err := filepath.Abs(imageFile)
+	if err != nil {
+		t.Fatalf("failed to get absolute path of file %q: %v", imageFile, err)
+	}
+	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "save", taggedImage, imagePath))
+	if err != nil {
+		t.Fatalf("saving image from minikube: %v\n%s", err, rr.Output())
+	}
+
+	// load image from file
+	rr, err = Run(t, exec.CommandContext(ctx, "docker", "load", "-i", imagePath))
+	if err != nil {
+		t.Fatalf("failed to load image to file: %v\n%s", err, rr.Output())
+	}
+	defer os.Remove(imageFile)
+
+	// make sure the image was correctly loaded
+	rr, err = Run(t, exec.CommandContext(ctx, "docker", "images", name))
+	if err != nil {
+		t.Fatalf("listing images: %v\n%s", err, rr.Output())
+	}
+	if !strings.Contains(rr.Output(), tag) {
+		t.Fatalf("expected %s to be loaded but the image is not there", taggedImage)
+	}
+
+}
+
 func inspectImage(ctx context.Context, t *testing.T, profile string, image string) (*RunResult, error) {
 	var cmd *exec.Cmd
 	if ContainerRuntime() == "docker" {
@@ -342,7 +490,7 @@ func listImages(ctx context.Context, t *testing.T, profile string) (*RunResult,
 // validateBuildImage makes sures that `minikube image build` works as expected
 func validateBuildImage(ctx context.Context, t *testing.T, profile string) {
 	if NoneDriver() {
-		t.Skip("load image not available on none driver")
+		t.Skip("image build not available on none driver")
 	}
 	if GithubActionRunner() && runtime.GOOS == "darwin" {
 		t.Skip("skipping on github actions and darwin, as this test requires a running docker daemon")
@@ -350,10 +498,6 @@ func validateBuildImage(ctx context.Context, t *testing.T, profile string) {
 	defer PostMortemLogs(t, profile)
 
 	newImage := fmt.Sprintf("localhost/my-image:%s", profile)
-	if ContainerRuntime() == "containerd" {
-		startBuildkit(ctx, t, profile)
-		// unix:///run/buildkit/buildkitd.sock
-	}
 
 	// try to build the new image with minikube
 	rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "build", "-t", newImage, filepath.Join(*testdataDir, "build")))
@@ -379,16 +523,6 @@ func validateBuildImage(ctx context.Context, t *testing.T, profile string) {
 	}
 }
 
-func startBuildkit(ctx context.Context, t *testing.T, profile string) {
-	// sudo systemctl start buildkit.socket
-	cmd := exec.CommandContext(ctx, Target(), "ssh", "-p", profile, "--", "nohup",
-		"sudo", "-b", "buildkitd", "--oci-worker=false",
-		"--containerd-worker=true", "--containerd-worker-namespace=k8s.io")
-	if rr, err := Run(t, cmd); err != nil {
-		t.Fatalf("%s failed: %v", rr.Command(), err)
-	}
-}
-
 // validateListImages makes sures that `minikube image ls` works as expected
 func validateListImages(ctx context.Context, t *testing.T, profile string) {
 	if NoneDriver() {
@@ -429,53 +563,76 @@ func validateDockerEnv(ctx context.Context, t *testing.T, profile string) {
 		t.Skipf("only validate docker env with docker container runtime, currently testing %s", cr)
 	}
 	defer PostMortemLogs(t, profile)
-	mctx, cancel := context.WithTimeout(ctx, Seconds(120))
-	defer cancel()
-	var rr *RunResult
-	var err error
+
+	type ShellTest struct {
+		name          string
+		commandPrefix []string
+		formatArg     string
+	}
+
+	windowsTests := []ShellTest{
+		{"powershell", []string{"powershell.exe", "-NoProfile", "-NonInteractive"}, "%[1]s -p %[2]s docker-env | Invoke-Expression ; "},
+	}
+	posixTests := []ShellTest{
+		{"bash", []string{"/bin/bash", "-c"}, "eval $(%[1]s -p %[2]s docker-env) && "},
+	}
+
+	tests := posixTests
 	if runtime.GOOS == "windows" {
-		c := exec.CommandContext(mctx, "powershell.exe", "-NoProfile", "-NonInteractive", Target()+" -p "+profile+" docker-env | Invoke-Expression ;"+Target()+" status -p "+profile)
-		rr, err = Run(t, c)
-	} else {
-		c := exec.CommandContext(mctx, "/bin/bash", "-c", "eval $("+Target()+" -p "+profile+" docker-env) && "+Target()+" status -p "+profile)
-		// we should be able to get minikube status with a bash which evaled docker-env
-		rr, err = Run(t, c)
-	}
-	if mctx.Err() == context.DeadlineExceeded {
-		t.Errorf("failed to run the command by deadline. exceeded timeout. %s", rr.Command())
-	}
-	if err != nil {
-		t.Fatalf("failed to do status after eval-ing docker-env. error: %v", err)
-	}
-	if !strings.Contains(rr.Output(), "Running") {
-		t.Fatalf("expected status output to include 'Running' after eval docker-env but got: *%s*", rr.Output())
-	}
-	if !strings.Contains(rr.Output(), "in-use") {
-		t.Fatalf("expected status output to include `in-use` after eval docker-env but got *%s*", rr.Output())
+		tests = windowsTests
 	}
+	for _, tc := range tests {
+		t.Run(tc.name, func(t *testing.T) {
+			mctx, cancel := context.WithTimeout(ctx, Seconds(120))
+			defer cancel()
 
-	mctx, cancel = context.WithTimeout(ctx, Seconds(60))
-	defer cancel()
-	// do a eval $(minikube -p profile docker-env) and check if we are point to docker inside minikube
-	if runtime.GOOS == "windows" { // testing docker-env eval in powershell
-		c := exec.CommandContext(mctx, "powershell.exe", "-NoProfile", "-NonInteractive", Target()+" -p "+profile+" docker-env | Invoke-Expression ; docker images")
-		rr, err = Run(t, c)
-	} else {
-		c := exec.CommandContext(mctx, "/bin/bash", "-c", "eval $("+Target()+" -p "+profile+" docker-env) && docker images")
-		rr, err = Run(t, c)
-	}
+			command := make([]string, len(tc.commandPrefix)+1)
+			// Would use "copy" built-in here, but that is shadowed by "copy" package
+			for i, v := range tc.commandPrefix {
+				command[i] = v
+			}
 
-	if mctx.Err() == context.DeadlineExceeded {
-		t.Errorf("failed to run the command in 30 seconds. exceeded 30s timeout. %s", rr.Command())
-	}
+			formattedArg := fmt.Sprintf(tc.formatArg, Target(), profile)
 
-	if err != nil {
-		t.Fatalf("failed to run minikube docker-env. args %q : %v ", rr.Command(), err)
-	}
+			// we should be able to get minikube status with a shell which evaled docker-env
+			command[len(command)-1] = formattedArg + Target() + " status -p " + profile
+			c := exec.CommandContext(mctx, command[0], command[1:]...)
+			rr, err := Run(t, c)
 
-	expectedImgInside := "gcr.io/k8s-minikube/storage-provisioner"
-	if !strings.Contains(rr.Output(), expectedImgInside) {
-		t.Fatalf("expected 'docker images' to have %q inside minikube. but the output is: *%s*", expectedImgInside, rr.Output())
+			if mctx.Err() == context.DeadlineExceeded {
+				t.Errorf("failed to run the command by deadline. exceeded timeout. %s", rr.Command())
+			}
+			if err != nil {
+				t.Fatalf("failed to do status after eval-ing docker-env. error: %v", err)
+			}
+			if !strings.Contains(rr.Output(), "Running") {
+				t.Fatalf("expected status output to include 'Running' after eval docker-env but got: *%s*", rr.Output())
+			}
+			if !strings.Contains(rr.Output(), "in-use") {
+				t.Fatalf("expected status output to include `in-use` after eval docker-env but got *%s*", rr.Output())
+			}
+
+			mctx, cancel = context.WithTimeout(ctx, Seconds(60))
+			defer cancel()
+
+			// do a eval $(minikube -p profile docker-env) and check if we are point to docker inside minikube
+			command[len(command)-1] = formattedArg + "docker images"
+			c = exec.CommandContext(mctx, command[0], command[1:]...)
+			rr, err = Run(t, c)
+
+			if mctx.Err() == context.DeadlineExceeded {
+				t.Errorf("failed to run the command in 30 seconds. exceeded 30s timeout. %s", rr.Command())
+			}
+
+			if err != nil {
+				t.Fatalf("failed to run minikube docker-env. args %q : %v ", rr.Command(), err)
+			}
+
+			expectedImgInside := "gcr.io/k8s-minikube/storage-provisioner"
+			if !strings.Contains(rr.Output(), expectedImgInside) {
+				t.Fatalf("expected 'docker images' to have %q inside minikube. but the output is: *%s*", expectedImgInside, rr.Output())
+			}
+		})
 	}
 }
 
@@ -815,7 +972,7 @@ func validateDashboardCmd(ctx context.Context, t *testing.T, profile string) {
 	mctx, cancel := context.WithTimeout(ctx, Seconds(300))
 	defer cancel()
 
-	args := []string{"dashboard", "--url", "-p", profile, "--alsologtostderr", "-v=1"}
+	args := []string{"dashboard", "--url", "--port", "36195", "-p", profile, "--alsologtostderr", "-v=1"}
 	ss, err := Start(t, exec.CommandContext(mctx, Target(), args...))
 	if err != nil {
 		t.Errorf("failed to run minikube dashboard. args %q : %v", args, err)
@@ -976,10 +1133,22 @@ func validateCacheCmd(ctx context.Context, t *testing.T, profile string) {
 				t.Skipf("failed to build docker image, skipping local test: %v", err)
 			}
 
+			defer func() {
+				_, err := Run(t, exec.CommandContext(ctx, "docker", "rmi", img))
+				if err != nil {
+					t.Errorf("failed to delete local image %q, err %v", img, err)
+				}
+			}()
+
 			rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "cache", "add", img))
 			if err != nil {
 				t.Errorf("failed to 'cache add' local image %q. args %q err %v", img, rr.Command(), err)
 			}
+
+			rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "cache", "delete", img))
+			if err != nil {
+				t.Errorf("failed to 'cache delete' local image %q. args %q err %v", img, rr.Command(), err)
+			}
 		})
 
 		t.Run("delete_k8s.gcr.io/pause:3.3", func(t *testing.T) {
@@ -1528,11 +1697,23 @@ func testCert() string {
 	return fmt.Sprintf("%d.pem", os.Getpid())
 }
 
-// localTestCertPath is where the test file will be synced into the VM
+// testFileCert is name of the test certificate installed
+func testFileCert() string {
+	return fmt.Sprintf("%d2.pem", os.Getpid())
+}
+
+// localTestCertPath is where certs can be synced from the local host into the VM
+// precisely, it's $MINIKUBE_HOME/certs
 func localTestCertPath() string {
 	return filepath.Join(localpath.MiniPath(), "/certs", testCert())
 }
 
+// localTestCertFilesPath is an alternate location where certs can be synced into the minikube VM
+// precisely, it's $MINIKUBE_HOME/files/etc/ssl/certs
+func localTestCertFilesPath() string {
+	return filepath.Join(localpath.MiniPath(), "/files/etc/ssl/certs", testFileCert())
+}
+
 // localEmptyCertPath is where the test file will be synced into the VM
 func localEmptyCertPath() string {
 	return filepath.Join(localpath.MiniPath(), "/certs", fmt.Sprintf("%d_empty.pem", os.Getpid()))
@@ -1574,6 +1755,30 @@ func setupFileSync(ctx context.Context, t *testing.T, profile string) {
 		t.Errorf("%s size=%d, want %d", localTestCertPath(), got.Size(), want.Size())
 	}
 
+	testPem2 := filepath.Join(*testdataDir, "minikube_test2.pem")
+	tmpPem2 := localTestCertFilesPath() + ".pem"
+	if err := copy.Copy(testPem2, tmpPem2); err != nil {
+		t.Fatalf("failed to copy %s: %v", testPem2, err)
+	}
+
+	if err := os.Rename(tmpPem2, localTestCertFilesPath()); err != nil {
+		t.Fatalf("failed to rename %s: %v", tmpPem2, err)
+	}
+
+	want, err = os.Stat(testPem2)
+	if err != nil {
+		t.Fatalf("stat failed: %v", err)
+	}
+
+	got, err = os.Stat(localTestCertFilesPath())
+	if err != nil {
+		t.Fatalf("stat failed: %v", err)
+	}
+
+	if want.Size() != got.Size() {
+		t.Errorf("%s size=%d, want %d", localTestCertFilesPath(), got.Size(), want.Size())
+	}
+
 	// Create an empty file just to mess with people
 	if _, err := os.Create(localEmptyCertPath()); err != nil {
 		t.Fatalf("create failed: %v", err)
@@ -1608,7 +1813,7 @@ func validateFileSync(ctx context.Context, t *testing.T, profile string) {
 	}
 }
 
-// validateCertSync to check existence of the test certificate
+// validateCertSync checks to make sure a custom cert has been copied into the minikube guest and installed correctly
 func validateCertSync(ctx context.Context, t *testing.T, profile string) {
 	defer PostMortemLogs(t, profile)
 
@@ -1642,6 +1847,33 @@ func validateCertSync(ctx context.Context, t *testing.T, profile string) {
 			t.Errorf("failed verify pem file. minikube_test.pem -> %s mismatch (-want +got):\n%s", vp, diff)
 		}
 	}
+
+	testPem2 := filepath.Join(*testdataDir, "minikube_test2.pem")
+	want, err = ioutil.ReadFile(testPem2)
+	if err != nil {
+		t.Errorf("test file not found: %v", err)
+	}
+
+	// Check both the installed & reference certs (they should be symlinked)
+	paths = []string{
+		path.Join("/etc/ssl/certs", testFileCert()),
+		path.Join("/usr/share/ca-certificates", testFileCert()),
+		// hashed path generated by: 'openssl x509 -hash -noout -in testCert()'
+		"/etc/ssl/certs/3ec20f2e.0",
+	}
+	for _, vp := range paths {
+		t.Logf("Checking for existence of %s within VM", vp)
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "ssh", fmt.Sprintf("sudo cat %s", vp)))
+		if err != nil {
+			t.Errorf("failed to check existence of %q inside minikube. args %q: %v", vp, rr.Command(), err)
+		}
+
+		// Strip carriage returned by ssh
+		got := strings.ReplaceAll(rr.Stdout.String(), "\r", "")
+		if diff := cmp.Diff(string(want), got); diff != "" {
+			t.Errorf("failed verify pem file. minikube_test2.pem -> %s mismatch (-want +got):\n%s", vp, diff)
+		}
+	}
 }
 
 // validateNotActiveRuntimeDisabled asserts that for a given runtime, the other runtimes disabled, for example for containerd runtime, docker and crio needs to be not running
