@@ -33,6 +33,7 @@ import (
 	"github.com/google/go-cmp/cmp"
 	"k8s.io/minikube/pkg/minikube/bootstrapper/images"
 	"k8s.io/minikube/pkg/minikube/constants"
+	"k8s.io/minikube/pkg/minikube/detect"
 )
 
 // TestStartStop tests starting, stopping and restarting a minikube clusters with various Kubernetes versions and configurations
@@ -76,6 +77,16 @@ func TestStartStop(t *testing.T) {
 			}},
 		}
 
+		if detect.IsCloudShell() {
+			tests = []struct {
+				name    string
+				version string
+				args    []string
+			}{
+				{"cloud-shell", constants.DefaultKubernetesVersion, []string{}},
+			}
+		}
+
 		for _, tc := range tests {
 			tc := tc
 			t.Run(tc.name, func(t *testing.T) {
